macro_rules! emit {
($source: expr, $event: expr) => { ... };
}Expand description
Emit event. As methods can’t do mutable reborrowing correctly, you should use this macro.
macro_rules! emit {
($source: expr, $event: expr) => { ... };
}Emit event. As methods can’t do mutable reborrowing correctly, you should use this macro.